@@ -5,17 +5,17 @@
  *                                                                         *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2004 Insecure.Com LLC. Nmap       *
- * is also a registered trademark of Insecure.Com LLC.  This program is    *
- * free software; you may redistribute and/or modify it under the          *
- * terms of the GNU General Public License as published by the Free        *
- * Software Foundation; Version 2.  This guarantees your right to use,     *
- * modify, and redistribute this software under certain conditions.  If    *
- * you wish to embed Nmap technology into proprietary software, we may be  *
- * willing to sell alternative licenses (contact sales@insecure.com).      *
- * Many security scanner vendors already license Nmap technology such as  *
- * our remote OS fingerprinting database and code, service/version         *
- * detection system, and port scanning code.                               *
+ * The Nmap Security Scanner is (C) 1996-2006 Insecure.Com LLC. Nmap is    *
+ * also a registered trademark of Insecure.Com LLC.  This program is free  *
+ * software; you may redistribute and/or modify it under the terms of the  *
+ * GNU General Public License as published by the Free Software            *
+ * Foundation; Version 2 with the clarifications and exceptions described  *
+ * below.  This guarantees your right to use, modify, and redistribute     *
+ * this software under certain conditions.  If you wish to embed Nmap      *
+ * technology into proprietary software, we sell alternative licenses      *
+ * (contact sales@insecure.com).  Dozens of software vendors already       *
+ * license Nmap technology such as host discovery, port scanning, OS       *
+ * detection, and version detection.                                       *
  *                                                                         *
  * Note that the GPL places important restrictions on "derived works", yet *
  * it does not provide a detailed definition of that term.  To avoid       *
@@ -38,7 +38,7 @@
  * These restrictions only apply when you actually redistribute Nmap.  For *
  * example, nothing stops you from writing and selling a proprietary       *
  * front-end to Nmap.  Just distribute it by itself, and point people to   *
- * http://www.insecure.org/nmap/ to download Nmap.                         *
+ * http://insecure.org/nmap/ to download Nmap.                             *
  *                                                                         *
  * We don't consider these to be added restrictions on top of the GPL, but *
  * just a clarification of how we interpret "derived works" as it applies  *
@@ -50,10 +50,10 @@
  * If you have any questions about the GPL licensing restrictions on using *
  * Nmap in non-GPL works, we would be happy to help.  As mentioned above,  *
  * we also offer alternative license to integrate Nmap into proprietary    *
- * applications and appliances.  These contracts have been sold to many    *
- * security vendors, and generally include a perpetual license as well as  *
- * providing for priority support and updates as well as helping to fund   *
- * the continued development of Nmap technology.  Please email             *
+ * applications and appliances.  These contracts have been sold to dozens  *
+ * of software vendors, and generally include a perpetual license as well  *
+ * as providing for priority support and updates as well as helping to     *
+ * fund the continued development of Nmap technology.  Please email        *
  * sales@insecure.com for further information.                             *
  *                                                                         *
  * As a special exception to the GPL terms, Insecure.Com LLC grants        *
@@ -97,7 +97,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: utils.h 3048 2006-01-19 07:29:12Z fyodor $ */
+/* $Id: utils.h 3994 2006-09-16 02:25:20Z fyodor $ */
 
 #ifndef UTILS_H
 #define UTILS_H
@@ -117,7 +117,6 @@
 #include <netinet/in.h>
 #endif
 
-#include <sys/time.h>
 #include <assert.h>
 #include <sys/mman.h>
 #include "config.h"
@@ -142,9 +141,12 @@
 #include "nmap.h"
 #include "global_structures.h"
 
+/* Arithmatic difference modulo 2^32 */
 #ifndef MOD_DIFF
-#define MOD_DIFF(a,b) ((unsigned long) (MIN((unsigned long)(a) - (unsigned long ) (b), (unsigned long )(b) - (unsigned long) (a))))
+#define MOD_DIFF(a,b) ((u32) (MIN((u32)(a) - (u32 ) (b), (u32 )(b) - (u32) (a))))
 #endif
+
+/* Arithmatic difference modulo 2^16 */
 #ifndef MOD_DIFF_USHORT
 #define MOD_DIFF_USHORT(a,b) ((MIN((unsigned short)((unsigned short)(a) - (unsigned short ) (b)), (unsigned short) ((unsigned short )(b) - (unsigned short) (a)))))
 #endif
@@ -207,11 +209,6 @@ char *chomp(char *string);
 // is sent.  Returns -1 if there is an error, or len if the full length was sent.
 int Send(int sd, const void *msg, size_t len, int flags);
 
-ssize_t Write(int fd, const void *buf, size_t count);
-
-unsigned long gcd_ulong(unsigned long a, unsigned long b);
-unsigned int gcd_uint(unsigned int a, unsigned int b);
-unsigned long gcd_n_ulong(long nvals, unsigned long *val);
 unsigned int gcd_n_uint(int nvals, unsigned int *val);
 
 int arg_parse(const char *command, char ***argv);
@@ -232,11 +229,23 @@ long tval2msecs(char *tspec);
    str is returned. */
 char *cstring_unescape(char *str, unsigned int *len);
 
-#ifndef HAVE_USLEEP
-#ifdef HAVE_NANOSLEEP
-void usleep(unsigned long usec);
-#endif
-#endif
+/* This function converts zero-terminated 'txt' string to binary 'data'.
+   It is used to parse user input for ip options. Some examples of possible input
+   strings and results:
+   	'\x01*2\xA2'	-> [0x01,0x01,0xA2]	// with 'x' number is parsed in hex
+   	'\01\01\255'	-> [0x01,0x01,0xFF]	// without 'x' its in decimal
+   	'\x01\x00*2'	-> [0x01,0x00,0x00]	// '*' is copying char
+   	'R'		-> Record Route with 9 slots
+   	'S 192.168.0.1 172.16.0.1' -> Strict Route with 2 slots
+   	'L 192.168.0.1 172.16.0.1' -> Loose Route with 2 slots
+   	'T'		-> Record Timestamp with 9 slots
+   	'U'		-> Record Timestamp and Ip Address with 4 slots
+*/
+int parse_ip_options(char *txt, u8 *data, int datalen, int* firsthopoff, int* lasthopoff);
+
+void bintohexstr(char *buf, int buflen, char *src, int srclen);
+
+char* print_ip_options(u8* ipopt, int ipoptlen);
 
 #ifndef HAVE_STRERROR
 char *strerror(int errnum);
@@ -264,15 +273,7 @@ int numberlist2array(char *expr, u16 *dest, int destsize, char **errorstr,
 char *mmapfile(char *fname, int *length, int openflags);
 
 #ifdef WIN32
-#define PROT_READ       0x1             /* page can be read */
-#define PROT_WRITE      0x2             /* page can be written */
-#define PROT_EXEC       0x4             /* page can be executed */
-#define PROT_NONE       0x0             /* page can not be accessed */
-
-#define MAP_SHARED      0x01            /* Share changes */
-
 int win32_munmap(char *filestr, int filelen);
-
 #endif /* WIN32 */
 
 #endif /* UTILS_H */
